<!--
 * @Description: 流程审核中驳回时输入意见弹层(单条驳回)
-->
<template>
    <el-dialog v-dialogDrag
        title="驳回信息"
        :visible.sync="visible"
        v-if="visible"
        width="50%"
        top="10vh"
        :close-on-click-modal="false"
        append-to-body
        class="dialog-box"
    >
        <el-form
            ref="form"
            :model="tableData"
            :rules="rules"
            label-width="80px"
            label-position="top"
        >
            <el-table :data="tableData.data" border style="width: 100%">
                <el-table-column
                    label="驳回原因"
                    align="center"
                    min-width="180"
                >
                    <template v-slot="{row, $index}">
                        <el-form-item
                            :prop="'data.' + $index + '.detail'"
                            :rules="rules.detail"
                        >
                            <el-input
                                type="textarea"
                                placeholder="请输入详细驳回原因..."
                                :autosize="{minRows: 2, maxRows: 10}"
                                v-model="row.detail"
                            ></el-input>
                        </el-form-item>
                    </template>
                </el-table-column>
            </el-table>
        </el-form>
        <div slot="footer" class="dialog-footer">
            <el-button type="danger" @click="handleOverrule"> 驳回 </el-button>
            <el-button @click="close">取消</el-button>
        </div>
    </el-dialog>
</template>

<script>
export default {
    name: 'RejectInfoDialog',
    data() {
        return {
            visible: false,
            approvalComments: [],
            bhyyList: [],
            inptShow: false,
            text: '',
            api: '',
            status: '',
            form: {},
            rules: {
                detail: {
                    required: true,
                    message: '请输入详细驳回原因',
                    trigger: 'blur',
                },
            },
            tableData: {
                data: [{type: '', detail: ''}],
            },
            changeIndex: -1,
        }
    },
    created() {
        let data = JSON.parse(sessionStorage.getItem('dict_data'))
        this.bhyyList = data.bhyy
    },
    methods: {
        open(api, status) {
            this.api = api
            this.status = status
            this.form = {}
            this.inptShow = false
            this.visible = true
        },
        close() {
            this.visible = false
            this.tableData.data = [{type: '', detail: ''}]
            this.changeIndex = -1
            this.$refs.form.resetFields()
        },
        setInputShow(e, index) {
            if (index != this.changeIndex && e) {
                this.tableData.data.push({type: '', detail: ''})
                this.changeIndex = index
            }
        },
        handleOverrule() {
            this.$nextTick(() => {
                this.$refs.form.validate((valid) => {
                    if (valid) {
                        let approvalComments = this.tableData.data[0].detail
                        this.$emit(
                            'sendRejectInfo',
                            approvalComments,
                            this.api,
                            this.status
                        )
                        this.close()
                    }
                })
            })
        },
        addResult() {
            this.tableData.data.push({type: '', detail: ''})
        },
        deleteDate(index) {
            this.tableData.data.splice(index, 1)
        },
    },
}
</script>

<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';

.add-btn {
  font-size: 18px;
  font-weight: bold;
  cursor: pointer;
  color: $--color-primary;
}

.del-btn {
  font-size: 18px;
  font-weight: bold;
  color: $--color-danger;
  cursor: pointer;
}
.dialog-box {
    overflow: hidden;
}
</style>
